@@ -170,6 +170,10 @@ set( 'DOCHAZKA_LDAP', 0 );
 #     Autocreate unknown users if found in LDAP
 set( 'DOCHAZKA_LDAP_AUTOCREATE', 0 );
 
+# DOCHAZKA_LDAP_AUTOCREATE_AS
+#     Priv level to assign to LDAP-autocreated users
+set( 'DOCHAZKA_LDAP_AUTOCREATE_AS', 'active' );
+
 # DOCHAZKA_LDAP_SERVER
 #     LDAP server for LDAP authentication
 #     make sure to include either 'ldap://' or 'ldaps://'
