@@ -40,17 +40,17 @@
 
 # 
 set( 'SQL_EMPLOYEE_SELECT_BY_EID', q/
-      SELECT eid, sec_id, nick, fullname, email, passhash, salt, remark
+      SELECT eid, sec_id, nick, fullname, email, passhash, salt, supervisor, remark
       FROM employees WHERE eid=?/ );
 
 # 
 set( 'SQL_EMPLOYEE_SELECT_BY_SEC_ID', q/
-      SELECT eid, sec_id, nick, fullname, email, passhash, salt, remark
+      SELECT eid, sec_id, nick, fullname, email, passhash, salt, supervisor, remark
       FROM employees WHERE sec_id=?/ );
 
 #
 set( 'SQL_EMPLOYEE_SELECT_BY_NICK', q/
-      SELECT eid, sec_id, nick, fullname, email, passhash, salt, remark
+      SELECT eid, sec_id, nick, fullname, email, passhash, salt, supervisor, remark
       FROM employees WHERE nick=?/ );
 
 #
@@ -65,7 +65,7 @@ set( 'SQL_EMPLOYEE_SCHEDULE_AT_TIMESTAMP', q/
 
 # 
 set( 'SQL_EMPLOYEE_SELECT_MULTIPLE_BY_NICK', q/
-      SELECT eid, sec_id, nick, fullname, email, passhash, salt, remark
+      SELECT eid, sec_id, nick, fullname, email, passhash, salt, supervisor, remark
       FROM employees WHERE nick LIKE ?/ );
 
 #
@@ -79,23 +79,23 @@ set( 'SQL_EMPLOYEE_CURRENT_SCHEDULE', q/
 #
 set( 'SQL_EMPLOYEE_INSERT', q/
       INSERT INTO employees 
-                (sec_id, nick, fullname, email, passhash, salt, remark)
-      VALUES    (?,      ?,    ?,        ?,     ?,        ?,    ?) 
-      RETURNING  eid, sec_id, nick, fullname, email, passhash, salt, remark
+                (sec_id, nick, fullname, email, passhash, salt, supervisor, remark)
+      VALUES    (?,      ?,    ?,        ?,     ?,        ?,    ?,          ?) 
+      RETURNING  eid, sec_id, nick, fullname, email, passhash, salt, supervisor, remark
       / );
 
 #
 set( 'SQL_EMPLOYEE_UPDATE_BY_EID', q/
       UPDATE employees SET sec_id = ?, nick = ?, fullname = ?, email = ?,
-         passhash = ?, salt = ?, remark = ?  
+         passhash = ?, salt = ?, supervisor =?, remark = ?  
       WHERE eid = ?
-      RETURNING  eid, sec_id, nick, fullname, email, passhash, salt, remark
+      RETURNING  eid, sec_id, nick, fullname, email, passhash, salt, supervisor, remark
       / );
 
 #
 set( 'SQL_EMPLOYEE_DELETE', q/
       DELETE FROM employees WHERE eid = ? 
-      RETURNING  eid, sec_id, nick, fullname, email, passhash, salt, remark
+      RETURNING  eid, sec_id, nick, fullname, email, passhash, salt, supervisor, remark
       / );
 
 #
@@ -105,6 +105,23 @@ set( 'SQL_EMPLOYEE_COUNT_BY_PRIV_LEVEL', q/
       ) SELECT count(*) FROM emps_with_privs WHERE priv=?
       / );
 
+#
+set( 'SQL_EMPLOYEE_SELECT_NICKS_ALL', q/
+      SELECT nick FROM employees ORDER BY nick
+      / );
+
+#
+set( 'SQL_EMPLOYEE_SELECT_NICKS_BY_PRIV_LEVEL', q/
+      WITH emps_with_privs AS (
+          SELECT eid, nick, current_priv(eid) AS priv FROM employees
+      ) SELECT nick FROM emps_with_privs WHERE priv=? ORDER BY nick
+      / );
+
+#
+set( 'SQL_EMPLOYEE_SELECT_TEAM', q/
+     SELECT nick FROM employees WHERE supervisor = ? ORDER BY nick
+     / );
+
 #
 set( 'SQL_EMPLOYEE_PRIV_CHANGE_DURING_RANGE', q/
      SELECT priv_change_during_range( ?, ? )
