@@ -80,36 +80,43 @@ set( 'SQL_SCHEDINTVLS_DELETE', q/
 #     SQL to insert a single schedule
 #
 set( 'SQL_SCHEDULE_INSERT', q/
-      INSERT INTO schedules (schedule, remark, disabled) 
-      VALUES (?, ?, 'f')
-      RETURNING sid, schedule, remark, disabled
+      INSERT INTO schedules (scode, schedule, remark, disabled) 
+      VALUES (?, ?, ?, 'f')
+      RETURNING sid, scode, schedule, remark, disabled
       / );
 
 # SQL_SCHEDULE_UPDATE
-#     SQL query to update remark and disabled fields of a schedule record
+#     SQL query to update scode, remark, and disabled fields of a schedule record
 set( 'SQL_SCHEDULE_UPDATE', q/
-      UPDATE schedules SET remark = ?, disabled = ?
+      UPDATE schedules 
+      SET scode = ?, remark = ?, disabled = ?
       WHERE sid = ?
-      RETURNING sid, schedule, remark, disabled
+      RETURNING sid, scode, schedule, remark, disabled
       / );
 
 # SQL_SCHEDULE_DELETE
 #     SQL query to delete a row given a SID
 set( 'SQL_SCHEDULE_DELETE', q/
       DELETE FROM schedules WHERE sid = ?
-      RETURNING sid, schedule, remark, disabled
+      RETURNING sid, scode, schedule, remark, disabled
+      / );
+
+# SQL_SCHEDULE_SELECT_BY_SCODE
+#     SQL query to retrieve entire row given a SID
+set( 'SQL_SCHEDULE_SELECT_BY_SCODE', q/
+      SELECT sid, scode, schedule, remark, disabled FROM schedules WHERE scode = ? 
       / );
 
 # SQL_SCHEDULE_SELECT_BY_SID
 #     SQL query to retrieve entire row given a SID
 set( 'SQL_SCHEDULE_SELECT_BY_SID', q/
-      SELECT sid, schedule, remark, disabled FROM schedules WHERE sid = ? 
+      SELECT sid, scode, schedule, remark, disabled FROM schedules WHERE sid = ? 
       / );
 
-# SQL_SCHEDULES_SELECT_SID
-#     SQL query to retrieve SID given a schedule (JSON string)
-set( 'SQL_SCHEDULES_SELECT_SID', q/
-      SELECT sid FROM schedules WHERE schedule = ?
+# SQL_SCHEDULES_SELECT_BY_SCHEDULE
+#     SQL query to retrieve entire row given a schedule (JSON string)
+set( 'SQL_SCHEDULES_SELECT_BY_SCHEDULE', q/
+      SELECT sid, scode, schedule, remark, disabled FROM schedules WHERE schedule = ?
       / );
 
 # SQL_SCHEDULES_SELECT_SCHEDULE
@@ -121,7 +128,7 @@ set( 'SQL_SCHEDULES_SELECT_SCHEDULE', q/
 # SQL_SCHEDULES_SELECT_ALL_INCLUDING_DISABLED
 #     SQL query to retrieve all schedule records (JSON strings), including disabled ones
 set( 'SQL_SCHEDULES_SELECT_ALL_INCLUDING_DISABLED', q/
-      SELECT sid, schedule, remark, disabled 
+      SELECT sid, scode, schedule, remark, disabled 
       FROM schedules
       ORDER BY sid
       / );
@@ -129,7 +136,7 @@ set( 'SQL_SCHEDULES_SELECT_ALL_INCLUDING_DISABLED', q/
 # SQL_SCHEDULES_SELECT_ALL_EXCEPT_DISABLED
 #     SQL query to retrieve all non-disabled schedule records (JSON strings)
 set( 'SQL_SCHEDULES_SELECT_ALL_EXCEPT_DISABLED', q/
-      SELECT sid, schedule, remark, disabled 
+      SELECT sid, scode, schedule, remark, disabled 
       FROM schedules WHERE disabled != TRUE
       ORDER BY sid
       / );
@@ -142,6 +149,16 @@ set( 'SQL_SCHEDHISTORY_INSERT', q/
       RETURNING shid, eid, sid, effective, remark
       / );
 
+# SQL_SCHEDHISTORY_UPDATE
+#     SQL to update a single row from schedhistory table
+#
+set( 'SQL_SCHEDHISTORY_UPDATE', q/
+      UPDATE schedhistory 
+      SET sid = ?, effective = ?, remark = ?
+      WHERE shid = ?
+      RETURNING shid, eid, sid, effective, remark
+      / );
+
 # SQL_SCHEDHISTORY_DELETE
 #     SQL query to delete a schedhistory row
 set( 'SQL_SCHEDHISTORY_DELETE', q/
