@@ -58,11 +58,11 @@ App::Dochazka::REST - Dochazka REST server
 
 =head1 VERSION
 
-Version 0.443
+Version 0.458
 
 =cut
 
-our $VERSION = '0.443';
+our $VERSION = '0.458';
 
 
 =head2 Development status
@@ -1009,7 +1009,7 @@ for C<local> so it looks like this:
 For the audit triggers to work (and the application will not run otherwise), we
 must to add the following line to the end of C<postgresql.conf>:
 
-    dochazka.eid = -1;
+    dochazka.eid = -1
 
 Then, as root, we restart the postgresql service:
 
