@@ -42,6 +42,7 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $log $meta $site );
+use App::Dochazka qw( $today init_timepiece );
 use App::Dochazka::REST;
 use App::Dochazka::REST::ConnBank qw( $dbix_conn conn_status );
 use App::Dochazka::REST::ACL qw( check_acl );
@@ -68,11 +69,11 @@ App::Dochazka::REST::Auth - HTTP request authentication and authorization
 
 =head1 VERSION
 
-Version 0.443
+Version 0.458
 
 =cut
 
-our $VERSION = '0.443';
+our $VERSION = '0.458';
 
 
 
@@ -271,12 +272,31 @@ sub _authenticate {
                         nick => $nick,
                         remark => 'LDAP autocreate',
                     );
-                    $status = $emp->insert;
+                    my $faux_context = { 'dbix_conn' => $dbix_conn, 'current' => { 'eid' => 1 } };
+                    $status = $emp->insert( $faux_context );
                     if ( $status->not_ok ) {
                         $log->crit("Could not create $nick as new employee");
                         return $CELL->status_not_ok( 'DOCHAZKA_EMPLOYEE_AUTH' );
                     }
                     $log->notice( "Auto-created employee $nick, who was authenticated via LDAP" );
+                    if ( my $priv = $site->LDAP_LDAP_AUTOCREATE_AS ) {
+                        if ( $priv =~ m/^(passerby)|(inactive)|(active)$/ ) {
+                            init_timepiece();
+                            my $ph_obj = App::Dochazka::REST::Model::Privhistory->spawn(
+                                eid => $emp->eid,
+                                priv => $priv,
+                                effective => ( $today . ' 00:00' ),
+                                remark => 'LDAP autocreate',
+                            );
+                            $status = $ph_obj->insert( $faux_context );
+                            $log->error("Could not add priv history record for LDAP-autocreated " .
+                                " employee ->$nick<- ; reason was " . $status->text )
+                                if $status->not_ok;
+                        } else {
+                            $log->error( "Site configuration parameter LDAP_LDAP_AUTOCREATE_AS " .
+                                         "is invalid" );
+                        }
+                    }
                 } else {
                     $log->notice( "Authentication attempt from LDAP user $nick failed " . 
                                   "because the user is not in the database and " . 
@@ -289,7 +309,7 @@ sub _authenticate {
         }
 
         # load the employee object
-        my $emp = App::Dochazka::REST::Model::Employee->load_by_nick( $nick )->payload;
+        my $emp = App::Dochazka::REST::Model::Employee->load_by_nick( $dbix_conn, $nick )->payload;
         die "missing employee object in _authenticate" unless ref($emp) eq "App::Dochazka::REST::Model::Employee";
         return $CELL->status_ok( 'DOCHAZKA_EMPLOYEE_AUTH', payload => $emp );
     }
