@@ -40,10 +40,14 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $log $core $meta $site );
+use App::Dochazka qw( $today init_timepiece );
 use App::Dochazka::REST::ACL qw( check_acl_context acl_check_is_me acl_check_iid_lid );
 use App::Dochazka::REST::ConnBank qw( conn_status );
 use App::Dochazka::REST::Model::Activity;
-use App::Dochazka::REST::Model::Employee qw( noof_employees_by_priv );
+use App::Dochazka::REST::Model::Employee qw( 
+    list_employees_by_priv 
+    noof_employees_by_priv 
+);
 use App::Dochazka::REST::Model::Interval;
 use App::Dochazka::REST::Model::Lock;
 use App::Dochazka::REST::Model::Privhistory qw( get_privhistory );
@@ -55,11 +59,11 @@ use App::Dochazka::REST::Model::Shared qw(
     load_multiple 
     priv_by_eid 
     schedule_by_eid 
+    select_set_of_single_scalar_rows
 );
 use App::Dochazka::REST::ResourceDefs;
 use App::Dochazka::REST::Shared qw( :ALL );  # all the shared_* functions
 use App::Dochazka::REST::Util::Schedule qw( intervals_in_schedule );
-use App::Dochazka::REST::Util::Timestamp qw( $current_year $current_month );
 use Data::Dumper;
 use Module::Runtime qw( use_module );
 use Params::Validate qw( :all );
@@ -82,11 +86,11 @@ App::Dochazka::REST::Dispatch - Implementation of top-level resources
 
 =head1 VERSION
 
-Version 0.443
+Version 0.458
 
 =cut
 
-our $VERSION = '0.443';
+our $VERSION = '0.458';
 
 
 =head1 DESCRIPTION
@@ -157,7 +161,7 @@ sub handler_bugreport {
 
     # second pass
     return $CELL->status_ok( 'DISPATCH_BUGREPORT', 
-        payload => { report_bugs_to => $site->MREST_REPORT_BUGS_TO },
+        payload => { report_bugs_to => $site->DOCHAZKA_REPORT_BUGS_TO },
     );
 }
 
@@ -402,7 +406,7 @@ Generalized handler for resources that don't do anything.
 
 sub handler_noop {
     my ( $self, $pass ) = @_;
-    $log->debug( "Entering " . __PACKAGE__ . "::noop" );
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_noop" );
 
     # first pass
     return 1 if $pass == 1;
@@ -431,6 +435,7 @@ Handler for the C<session> resource.
 
 sub handler_session {
     my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_session" );
 
     # first pass
     return 1 if $pass == 1;
@@ -712,7 +717,7 @@ Handler for 'GET employee/count/?:priv' resource.
 
 sub handler_get_employee_count {
     my ( $self, $pass ) = @_;
-    $log->debug( "Entering App::Dochazka::REST::Dispatch::Employee::handler_get_employee_count" ); 
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_get_employee_count" ); 
 
     # first pass
     return 1 if $pass == 1;
@@ -728,6 +733,52 @@ sub handler_get_employee_count {
 }
 
 
+=head3 handler_get_employee_list
+
+Handler for 'GET employee/list/?:priv' resource.
+
+=cut
+
+sub handler_get_employee_list {
+    my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_get_employee_list" ); 
+
+    # first pass
+    return 1 if $pass == 1;
+
+    # second pass
+    my $result;
+    if ( my $priv = $self->context->{'mapping'}->{'priv'} ) {
+        $result = list_employees_by_priv( $self->context->{'dbix_conn'}, lc $priv );
+    } else {
+        $result = list_employees_by_priv( $self->context->{'dbix_conn'}, 'all' );
+    }
+    return $result;
+}
+
+
+=head3 handler_get_employee_team
+
+Handler for 'GET employee/team' resource.
+
+=cut
+
+sub handler_get_employee_team {
+    my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_get_employee_team" ); 
+
+    # first pass
+    return 1 if $pass == 1;
+
+    # second pass
+    my $employee_obj = $self->context->{'current_obj'};
+    my $dbix_conn = $self->context->{'dbix_conn'};
+    my $status = $employee_obj->team_nicks( $dbix_conn );
+
+    return $status;
+}
+
+
 =head3 handler_whoami
 
 Handler for GET requests on the 'whoami', 'employee/current', and
@@ -1008,6 +1059,43 @@ sub handler_get_employee_eid {
     return shared_get_employee( $self, $pass, 'EID', $self->context->{'mapping'}->{'eid'} );
 }
 
+=head3 handler_get_employee_eid_team
+
+Handler for 'GET employee/eid/:eid/team'
+
+=cut
+
+sub handler_get_employee_eid_team {
+    my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_get_employee_eid_team" ); 
+
+    if ( $pass == 1 ) {
+        return $self->handler_get_employee_eid( $pass );
+    }
+
+    my $context = $self->context;
+    my $dbix_conn = $context->{'dbix_conn'};
+    return $context->{'stashed_employee_object'}->team_nicks( $dbix_conn );
+}
+
+=head3 handler_get_employee_nick_team
+
+Handler for 'GET employee/nick/:nick/team'
+
+=cut
+
+sub handler_get_employee_nick_team {
+    my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_get_employee_nick_team" ); 
+
+    if ( $pass == 1 ) {
+        return $self->handler_get_employee_nick( $pass );
+    }
+
+    my $context = $self->context;
+    my $dbix_conn = $context->{'dbix_conn'};
+    return $context->{'stashed_employee_object'}->team_nicks( $dbix_conn );
+}
 
 =head3 handler_delete_employee_nick
 
@@ -1613,14 +1701,15 @@ sub handler_get_interval_summary {
         $context->{'stashed_values'}->[0] = $eid;
 
         # process the 'month' qualifier, so it at least has six digits
-        $log->debug( "current_year $current_year, current_month $current_month" );
+        my ( $this_year, $this_month ) = $today =~ m/^(\d{4})-(\d{2})/;
+        $log->debug( "year $this_year, month $this_month" );
         my $month;
         if ( $pl{'month'} ) {
             $month = sprintf( "%06d", $pl{'month'} );
         } else {
             # use the current month
-            my $month_str = sprintf( "%02d", $current_month );
-            my $year_str = sprintf( "%04d", $current_year );
+            my $month_str = sprintf( "%02d", $this_month );
+            my $year_str = sprintf( "%04d", $this_year );
             $month = $year_str . $month_str;
         }
 
