@@ -37,7 +37,16 @@ use strict;
 use warnings FATAL => 'all';
 use App::CELL qw( $CELL $log $meta $site );
 use App::Dochazka::REST::LDAP;
-use App::Dochazka::REST::Model::Shared qw( cud load load_multiple noof priv_by_eid schedule_by_eid select_single );
+use App::Dochazka::REST::Model::Shared qw( 
+    cud 
+    load 
+    load_multiple 
+    noof 
+    priv_by_eid 
+    schedule_by_eid 
+    select_single 
+    select_set_of_single_scalar_rows
+);
 use Carp;
 use Data::Dumper;
 use DBI qw(:sql_types);
@@ -63,11 +72,11 @@ App::Dochazka::REST::Model::Employee - Employee data model
 
 =head1 VERSION
 
-Version 0.443
+Version 0.458
 
 =cut
 
-our $VERSION = '0.443';
+our $VERSION = '0.458';
 
 
 
@@ -190,6 +199,8 @@ in the object)
 
 =item * L<load_by_nick> (loads a single employee into the object)
 
+=item * L<team_nicks> (returns list of nicks of employees whose supervisor is this employee)
+
 =back
 
 L<App::Dochazka::REST::Model::Employee> also exports some convenience
@@ -201,6 +212,8 @@ functions:
 
 =item * L<eid_exists> (given an EID, return true/false)
 
+=item * L<list_employees_by_priv> (given a priv level, return hash of employees with that priv level)
+
 =item * L<noof_employees_by_priv> (given a priv level, return number of employees with that priv level)
 
 =back
@@ -220,6 +233,8 @@ This module provides the following exports:
 
 =item L<eid_exists> - function
 
+=item L<list_employees_by_priv> - function
+
 =item L<noof_employees_by_priv> - function
 
 =back
@@ -227,8 +242,12 @@ This module provides the following exports:
 =cut
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( nick_exists eid_exists noof_employees_by_priv );
-
+our @EXPORT_OK = qw( 
+    nick_exists 
+    eid_exists 
+    list_employees_by_priv 
+    noof_employees_by_priv 
+);
 
 
 
@@ -311,7 +330,7 @@ sub insert {
         eid => $context->{'current'}->{'eid'},
         object => $self,
         sql => $site->SQL_EMPLOYEE_INSERT,
-        attrs => [ 'sec_id', 'nick', 'fullname', 'email', 'passhash', 'salt', 'remark' ],
+        attrs => [ 'sec_id', 'nick', 'fullname', 'email', 'passhash', 'salt', 'supervisor', 'remark' ],
     );
     return $status;
 }
@@ -339,7 +358,7 @@ sub update {
         eid => $context->{'current'}->{'eid'},
         object => $self,
         sql => $site->SQL_EMPLOYEE_UPDATE_BY_EID,
-        attrs => [ 'sec_id', 'nick', 'fullname', 'email', 'passhash', 'salt', 'remark', 'eid' ],
+        attrs => [ 'sec_id', 'nick', 'fullname', 'email', 'passhash', 'salt', 'supervisor', 'remark', 'eid' ],
     );
     return $status;
 }
@@ -382,6 +401,7 @@ sub load_by_eid {
     my ( $conn, $eid ) = validate_pos( @_, 
         { isa => 'DBIx::Connector' },
         { type => SCALAR },
+#        { type => SCALAR, regex => qr/^-?\d+$/ }, <-- causes a regression
     );
     $log->debug( "Entering " . __PACKAGE__ . "::load_by_eid with argument $eid" );
 
@@ -575,6 +595,42 @@ sub schedhistory_at_timestamp {
 }
 
 
+=head2 team_nicks
+
+Given a L<DBIx::Connector> object, return a status object that, if successful,
+will contain in the payload a list of employees whose supervisor is the
+employee corresponding to C<$self>.
+
+=cut
+
+sub team_nicks {
+    my $self = shift;
+    my ( $conn ) = validate_pos( @_,
+        { isa => 'DBIx::Connector' },
+    );
+    $log->debug( "Entering " . __PACKAGE__ . "::team_nicks for supervisor " . ( $self->nick || 'undefined' ) );
+
+    # no EID, no team
+    return $CELL->status_ok( 'TEAM', payload => [] ) unless $self->eid;
+
+    # if nick not populated, get it
+    $self->load_by_eid( $conn, $self->eid ) unless $self->nick;
+
+    my $status = select_set_of_single_scalar_rows( 
+        'conn' => $conn,
+        'sql' => $site->SQL_EMPLOYEE_SELECT_TEAM,
+        'keys' => [ $self->eid ],
+    );
+    return $status unless $status->ok;
+    return $CELL->status_ok( 
+        'DISPATCH_LIST_EMPLOYEE_NICKS_TEAM',
+        args => [ $self->nick ],
+        payload => $status->payload,
+    );
+}
+
+
+
 
 =head1 FUNCTIONS
 
@@ -605,6 +661,44 @@ BEGIN {
 }
 
 
+=head2 list_employees_by_priv
+
+Get employee nicks. Argument can be one of the following:
+
+    all admin active inactive passerby
+
+=cut
+
+sub list_employees_by_priv {
+    my ( $conn, $priv ) = validate_pos( @_,
+        { isa => 'DBIx::Connector' },
+        { type => SCALAR, regex => qr/^(all)|(admin)|(active)|(inactive)|(passerby)$/ },
+    );
+    $log->debug( "Entering " . __PACKAGE__ . "::list_employees_by_priv with priv $priv" );
+
+    my $nicks = [];  # reference to array of nicks
+    my $sql = '';    # SQL statement
+    my $keys_arrayref = [];   # reference to array of keys (may be empty)
+    if ( $priv eq 'all' ) {
+        $sql = $site->SQL_EMPLOYEE_SELECT_NICKS_ALL
+    } else {
+        $sql = $site->SQL_EMPLOYEE_SELECT_NICKS_BY_PRIV_LEVEL;
+        $keys_arrayref = [ $priv ];
+    }
+    my $status = select_set_of_single_scalar_rows( 
+        'conn' => $conn, 
+        'sql' => $sql, 
+        'keys' => $keys_arrayref,
+    );
+    return $status unless $status->ok;
+    
+    return $CELL->status_ok( 'DISPATCH_LIST_EMPLOYEE_NICKS', 
+        args => [ $priv ],
+        payload => $status->payload,
+    );
+}
+
+
 =head2 noof_employees_by_priv
 
 Get number of employees. Argument can be one of the following:
@@ -616,10 +710,12 @@ Get number of employees. Argument can be one of the following:
 sub noof_employees_by_priv {
     my ( $conn, $priv ) = validate_pos( @_,
         { isa => 'DBIx::Connector' },
-        { type => SCALAR },
+        { type => SCALAR, regex => qr/^(total)|(admin)|(active)|(inactive)|(passerby)$/ },
     );
     $log->debug( "Entering " . __PACKAGE__ . "::noof_employees_by_priv with priv $priv" );
 
+    $priv = lc $priv;
+
     if ( $priv eq 'total' ) {
         my $count = noof( $conn, 'employees' );
         return $CELL->status_ok( 
@@ -640,7 +736,6 @@ sub noof_employees_by_priv {
 }
 
 
-
 =head1 AUTHOR
 
 Nathan Cutler, C<< <presnypreklad@gmail.com> >>
