@@ -54,11 +54,11 @@ the data model
 
 =head1 VERSION
 
-Version 0.443
+Version 0.458
 
 =cut
 
-our $VERSION = '0.443';
+our $VERSION = '0.458';
 
 
 
@@ -114,6 +114,8 @@ Get total number of records in a data model table
 
 Run an arbitrary SELECT that returns 0 or 1 records
 
+=item * C<select_set_of_single_scalar_rows> 
+
 =back
 
 =cut
@@ -130,6 +132,7 @@ our @EXPORT_OK = qw(
     priv_by_eid 
     schedule_by_eid 
     select_single 
+    select_set_of_single_scalar_rows
 );
 
 
@@ -736,6 +739,48 @@ sub get_history {
 }
 
 
+=head2 select_set_of_single_scalar_rows
+
+Given DBIx::Connector object, an SQL statement, and a set of keys to bind
+into the SQL statement, assume that the statement can return 0-n records
+and that each record consists of a single field that must fit into a single
+scalar value.
+
+=cut
+
+sub select_set_of_single_scalar_rows {
+    my %ARGS = validate( @_, { 
+        conn => { isa => 'DBIx::Connector' },
+        sql => { type => SCALAR },
+        keys => { type => ARRAYREF },
+    } );
+    $log->debug( "Entering " . __PACKAGE__ . "::select_set_of_single_scalar_rows with
+        paramhash " . Dumper( \%ARGS ) );
+
+    my ( $status, $result_set );
+    try {
+        $ARGS{'conn'}->run( fixup => sub {
+            my $sth = $_->prepare( $ARGS{'sql'} );
+            my $bc = 0;
+            map {
+                $bc += 1;
+                $sth->bind_param( $bc, $_ || undef );
+            } @{ $ARGS{'keys'} };
+            $sth->execute();
+            # push results onto $nicks
+            while( defined( my $tmpres = $sth->fetchrow_arrayref() ) ) {
+                push @$result_set, @$tmpres;
+            }
+        } );
+    } catch {
+        $log->debug( 'Encountered DBI error' );
+        $status = $CELL->status_err( 'DOCHAZKA_DBI_ERR', args => [ $_ ] );
+    };
+
+    return $status if $status;
+    return $CELL->status_ok( 'RESULT_SET', payload => $result_set );
+}
+
 
 =head1 AUTHOR
 
