@@ -54,15 +54,15 @@ App::Dochazka::REST::ResourceDefs - Resource definitions
 
 =head1 VERSION
 
-Version 0.443
+Version 0.458
 
 =cut
 
-our $VERSION = '0.443';
+our $VERSION = '0.458';
 my $tsrange_validation = qr/^[[(].*,.*[])]$/;
 my $term_validation = qr/^[[:alnum:]_][[:alnum:]_-]*$/;
 my $date_validation = qr/^\d{2,4}-\d{1,2}-\d{1,2}$/;
-
+my $priv_validation = qr/^(admin)|(active)|(inactive)|(passerby)$/i;
 
 
 
@@ -355,6 +355,23 @@ EOH
 Shows the software version running on the present instance. The version displayed
 is taken from the C<$VERSION> package variable of the package specified in the
 C<MREST_APPLICATION_MODULE> site parameter.
+EOH
+    },
+
+    # /whoami
+    'whoami' => {
+        parent => '/',
+        handler => {
+            GET => 'handler_whoami',
+        },
+        acl_profile => 'passerby',
+        cli => 'whoami',
+        description => 'Display the current employee (i.e. the one we authenticated with)',
+        documentation => <<'EOH',
+=pod
+
+Displays the profile of the currently logged-in employee (same as
+"employee/current")
 EOH
     },
 
@@ -586,7 +603,7 @@ EOH
         acl_profile => 'admin', 
         cli => 'employee count',
         validations => {
-            'priv' => qr/^(admin)|(active)|(inactive)|(passerby)$/i,
+            'priv' => $priv_validation,
         },
         description => 'Display total count of employees (optionally by privlevel)',
         documentation => <<'EOH',
@@ -753,6 +770,48 @@ exists and nothing in the database refers to it).
 EOH
     },
 
+    # /employee/eid/:eid/team
+    'employee/eid/:eid/team' =>
+    { 
+        parent => 'employee/eid/:eid',
+        handler => {
+            GET => 'handler_get_employee_eid_team', 
+        },
+        acl_profile => 'admin',
+        cli => 'employee eid $EID team',
+        validations => {
+            eid => 'Int',
+        },
+        description => 'List the nicks of an employee\'s team members',
+        documentation => <<'EOH',
+=pod
+
+This resource enables administrators to list the nicks of team members
+of an arbitrary employee - i.e. that employee\'s direct reports.
+EOH
+    },
+
+    # /employee/list/?:priv
+    'employee/list/?:priv' =>
+    {
+        parent => 'employee',
+        handler => {
+            GET => 'handler_get_employee_list',
+        },
+        acl_profile => 'admin', 
+        cli => 'employee list [$PRIV]',
+        validations => {
+            'priv' => $priv_validation,
+        },
+        description => 'List nicks of employees',
+        documentation => <<'EOH',
+=pod
+
+This resource enables the administrator to easily list the nicks of
+employees. If priv is not given, all employees are listed.
+EOH
+    },
+
     # /employee/nick
     'employee/nick' =>
     {
@@ -840,6 +899,27 @@ in question.
 EOH
     },
 
+    # /employee/nick/:nick/team
+    'employee/nick/:nick/team' =>
+    { 
+        parent => 'employee/nick/:nick',
+        handler => {
+            GET => 'handler_get_employee_nick_team', 
+        },
+        acl_profile => 'admin',
+        cli => 'employee nick $nick team',
+        validations => {
+            nick => $term_validation,
+        },
+        description => 'List the nicks of an employee\'s team members',
+        documentation => <<'EOH',
+=pod
+
+This resource enables administrators to list the nicks of team members
+of an arbitrary employee - i.e. that employee\'s direct reports.
+EOH
+    },
+
     # /employee/search
     'employee/search' =>
     {
@@ -963,22 +1043,24 @@ looked up from the database.
 EOH
     },
 
-    # /whoami
-    'whoami' => {
-        parent => '/',
+    # /employee/team
+    'employee/team' =>
+    {
+        parent => 'employee',
         handler => {
-            GET => 'handler_whoami',
+            GET => 'handler_get_employee_team',
         },
-        acl_profile => 'passerby',
-        cli => 'whoami',
-        description => 'Display the current employee (i.e. the one we authenticated with)',
+        acl_profile => 'active', 
+        cli => 'team',
+        description => 'List nicks of the logged-in employee\'s team members',
         documentation => <<'EOH',
 =pod
 
-Displays the profile of the currently logged-in employee (same as
-"employee/current")
+This resource enables supervisors to easily list the nicks of
+employees in their team - i.e. their direct reports.
 EOH
     },
+
 };
 
 
@@ -1492,7 +1574,7 @@ EOH
     },
 
     # /interval/fillup/eid/:eid/:lower/:upper
-    '/interval/fillup/eid/:eid/:lower/:upper' => 
+    'interval/fillup/eid/:eid/:lower/:upper' => 
     {
         parent => 'interval/fillup',
         handler => {
@@ -1522,7 +1604,7 @@ EOH
     },
 
     # /interval/fillup/nick/:nick/:lower/:upper
-    '/interval/fillup/nick/:nick/:lower/:upper' => 
+    'interval/fillup/nick/:nick/:lower/:upper' => 
     {
         parent => 'interval/fillup',
         handler => {
@@ -1552,7 +1634,7 @@ EOH
     },
 
     # /interval/fillup/self/:lower/:upper
-    '/interval/fillup/self/:lower/:upper' => 
+    'interval/fillup/self/:lower/:upper' => 
     {
         parent => 'schedule',
         handler => {
