@@ -40,6 +40,7 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $meta $site );
+use App::Dochazka;
 use App::Dochazka::REST::ConnBank qw( $dbix_conn conn_status );
 use App::Dochazka::REST::Util qw( hash_the_password );
 use App::Dochazka::REST::Model::Privhistory qw( get_privhistory );
@@ -67,11 +68,11 @@ App::Dochazka::REST::Test - Test helper functions
 
 =head1 VERSION
 
-Version 0.443
+Version 0.458
 
 =cut
 
-our $VERSION = '0.443';
+our $VERSION = '0.458';
 
 
 
@@ -101,6 +102,7 @@ our @EXPORT = qw(
     gen_activity gen_employee gen_interval gen_lock
     gen_privhistory gen_schedhistory gen_schedule
     test_sql_success test_sql_failure do_select_single
+    test_employee_list
 );
 
 
@@ -162,6 +164,9 @@ sub initialize_unit {
     # add Web::Machine object to payload
     $status->payload( Web::Machine->new( resource => 'App::Dochazka::REST::Dispatch', )->to_app );
 
+    # initialize App::Dochazka package variables $t, $today, etc.
+    App::Dochazka::init_timepiece();
+
     return $status;
 }
 
@@ -761,4 +766,11 @@ sub do_select_single {
     return @{ $status->payload };
 }
     
+sub test_employee_list {
+    my ( $status, $nicks ) = @_;
+    is( $status->level, 'OK' );
+    is( $status->code, 'DISPATCH_LIST_EMPLOYEE_NICKS' );
+    is_deeply( $status->payload, $nicks );
+}
+
 1;
