@@ -36,8 +36,6 @@ use 5.012;
 use strict;
 use warnings FATAL => 'all';
 use DBI;
-use Time::Piece;
-use Time::Seconds;
 
 
 
@@ -51,11 +49,11 @@ App::Dochazka::REST::Util::Timestamp - date/time-related utilities
 
 =head1 VERSION
 
-Version 0.443
+Version 0.458
 
 =cut
 
-our $VERSION = '0.443';
+our $VERSION = '0.458';
 
 
 
@@ -75,18 +73,6 @@ This module provides the following exports:
 
 =over 
 
-=item C<$today> (string), e.g. '2014-07-09'
-
-=item C<$today_ts> (string), e.g. '2014-07-09 00:00:00'
-
-=item C<$yesterday> (string), e.g. '2014-07-08'
-
-=item C<$yesterday_ts> (string), e.g. '2014-07-08 00:00:00'
-
-=item C<$tomorrow> (string), e.g. '2014-07-10'
-
-=item C<$tomorrow_ts> (string), e.g. '2014-07-10 00:00:00'
-
 =item L<split_tsrange> (function)
 
 =item L<subtract_days> (function)
@@ -98,19 +84,12 @@ This module provides the following exports:
 =cut
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( $today $today_ts $yesterday $yesterday_ts $tomorrow
-    $tomorrow_ts $current_year $current_month subtract_days 
-    tsrange_equal );
+our @EXPORT_OK = qw( 
+    split_tsrange
+    subtract_days 
+    tsrange_equal 
+);
 
-our $t = localtime;
-our $today = $t->ymd;
-our $today_ts = $today . ' 00:00:00';
-our $yesterday = ($t - ONE_DAY)->ymd;
-our $yesterday_ts = $yesterday . ' 00:00:00';
-our $tomorrow = ($t + ONE_DAY)->ymd;
-our $tomorrow_ts = $tomorrow . ' 00:00:00';
-our $current_year = $t->year;
-our $current_month = $t->mon;
 
 
 
